@@ -1,7 +1,7 @@
 package Bencher::Backend;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2016-03-18'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 use strict;
@@ -2190,7 +2190,7 @@ sub bencher {
                 };
 
                 for my $k (sort keys %$it) {
-                    next unless $k =~ /^(seq|participant|dataset|item_.+|arg_.+)$/;
+                    next unless $k =~ /^(seq|participant|dataset|perl|modver|item_.+|arg_.+)$/;
                     push @columns, $k unless grep {$k eq $_} @columns;
                     $row->{$k} = $it->{$k};
                 }
@@ -2289,7 +2289,7 @@ Bencher::Backend - Backend for Bencher
 
 =head1 VERSION
 
-This document describes version 0.40 of Bencher::Backend (from Perl distribution Bencher-Backend), released on 2016-03-16.
+This document describes version 0.41 of Bencher::Backend (from Perl distribution Bencher-Backend), released on 2016-03-18.
 
 =head1 FUNCTIONS
 
