@@ -1,7 +1,7 @@
 package Bencher::Formatter::ScaleTime;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2016-03-18'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,6 +24,9 @@ sub munge_result {
     # pick an appropriate time unit & format the time
     my ($min, $max) = minmax(map {$_->{time}} @{$envres->[2]});
 
+    # workaround for bug RT#113117 (max sometimes undef)
+    $max //= $min;
+
     my ($unit, $factor);
     if ($max <= 1.5e-6) {
         $unit = "ns";
@@ -72,7 +75,7 @@ Bencher::Formatter::ScaleTime - Scale time to make it convenient
 
 =head1 VERSION
 
-This document describes version 0.40 of Bencher::Formatter::ScaleTime (from Perl distribution Bencher-Backend), released on 2016-03-16.
+This document describes version 0.41 of Bencher::Formatter::ScaleTime (from Perl distribution Bencher-Backend), released on 2016-03-18.
 
 =for Pod::Coverage .*
 
